Insert table button

Lisää taulu -nappi | Sisällysluettelo

Lisää taulu -nappi avaa alla näkyvän ikkunan. Tämä toimonto mahdollistaa taulujen luonnin.
Kenttien selitteet:

Sarakkeet | Taulussa olevien saraakkeiden määrä.
Rivit | Taulussa olevien rivien määrä.
Solun reunan ja sisällön väli | Taulun sisällä olevan solun reunan ja sisällön väli.
Solujen väli | Taulun sisällä olevien solujen väli.
Asettelu | Taulun asettelu.
Reuna | Reunan leveys.
Leveys | Taulun leveys pikseleinä.
Korkeus | Taulun korkeus pikseleinä.

Mene: Sisällysluetteloon | Alkuun